@@ -7,7 +7,7 @@ use Config;
 use Text::ParseWords qw( shellwords );
 
 # ABSTRACT: Compiler and linker wrapper for late optional Alien utilization
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 my @cflags_I;
@@ -100,7 +100,7 @@ Alien::Base::Wrapper - Compiler and linker wrapper for late optional Alien utili
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -128,8 +128,8 @@ From Makefile.PL:
  }
  else
  {
-   $cc = '$(FULLPERL) -Iinc -MAlien::Base::Wrapper=Alien::Libfoo -e cc --';
-   $ld = '$(FULLPERL) -Iinc -MAlien::Base::Wrapper=Alien::Libfoo -e ld --';
+   $cc = '$(FULLPERL) -MAlien::Base::Wrapper=Alien::Libfoo -e cc --';
+   $ld = '$(FULLPERL) -MAlien::Base::Wrapper=Alien::Libfoo -e ld --';
    $build_requires{'Alien::Libfoo'} = 0;
    $build_requires{'Alien::Base::Wrapper'} = 0;
  }
@@ -148,11 +148,25 @@ From Makefile.PL:
 
 B<Note>: this particular module is still somewhat experimental.
 
-This module provides a command line wrapper for L<Alien> modules that are
-based on L<Alien::Base>.  The idea is to eventually use this to allow optional
-use of L<Alien> modules by XS which cannot probe for a system library.
-Historically an XS module that wanted to use an L<Alien> had to I<always> have
-it as a prerequisite.
+This module provides a command line wrapper for your compiler and linker that use the 
+correct flags needed for compiling and linking with L<Alien> modules.  The problem that 
+this module attempts to solve is that compiler and linker flags typically need to be 
+determined at I<configure> time when a distribution is installed, meaning if you are going 
+to use an L<Alien> module, then it needs to be a configure prerequisite, even if the 
+library is already installed on the operating system.  With this module, you can use this 
+wrapper as the compiler and linker commands and delay computing the compiler and linker 
+flags to the build stage, and only if necessary.
+
+The author of this module believes it to be somewhat unnecessary.  L<Alien> modules based on 
+L<Alien::Base> have a number of prerequisites, but they well maintained and reliable, so 
+while there is a small cost in terms of extra dependencies, this is more than made up for 
+in reliability on systems where libraries that are do not typically come with commonly used 
+open source libraries.  Operating system vendors that are packaging XS perl modules may 
+disagree.
+
+If you wish to be extra minimal in your prerequisites you can bundle this module with
+your XS module, and use C<-Iinc>.  This module has no non-core prerequisites on Perl
+5.8.1 and better.
 
 For a working example, please see the C<Makefile.PL> that comes with L<Term::EditLine>.
 
